package com.ruoyi.ibs.list.service;

import com.ruoyi.ibs.list.domain.SocialSecurity;

import java.util.List;


/**
 * 个人视图社保信息Service接口
 * 
 * @author ruoyi
 * @date 2024-12-17
 */
public interface ISocialSecurityService 
{
    /**
     * 查询个人视图社保信息
     * 
     * @param id 个人视图社保信息主键
     * @return 个人视图社保信息
     */
    public SocialSecurity selectSocialSecurityById(Long id);

    /**
     * 查询个人视图社保信息列表
     * 
     * @param socialSecurity 个人视图社保信息
     * @return 个人视图社保信息集合
     */
    public List<SocialSecurity> selectSocialSecurityList(SocialSecurity socialSecurity);

    /**
     * 新增个人视图社保信息
     * 
     * @param socialSecurity 个人视图社保信息
     * @return 结果
     */
    public int insertSocialSecurity(SocialSecurity socialSecurity);

    /**
     * 修改个人视图社保信息
     * 
     * @param socialSecurity 个人视图社保信息
     * @return 结果
     */
    public int updateSocialSecurity(SocialSecurity socialSecurity);

    /**
     * 批量删除个人视图社保信息
     * 
     * @param ids 需要删除的个人视图社保信息主键集合
     * @return 结果
     */
    public int deleteSocialSecurityByIds(Long[] ids);

    /**
     * 删除个人视图社保信息信息
     * 
     * @param id 个人视图社保信息主键
     * @return 结果
     */
    public int deleteSocialSecurityById(Long id);
}
